// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: ByteArrayInputStream.h,v 1.6 2003/09/13 08:46:07 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_BYTEARRAYINPUTSTREAM_H
# define INCLUDE_JAKELIB2_IO_BYTEARRAYINPUTSTREAM_H
# include "InputStream.h"

namespace jakelib {
  namespace util {
    class ByteArray;
  }
  namespace io {

    /**
     * This class allows an array of bytes to be read as an input stream.
     *
     * @class ByteArrayInputStream
     * @version $Id: ByteArrayInputStream.h,v 1.6 2003/09/13 08:46:07 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class ByteArrayInputStream : public InputStream
    {
    public:

      ByteArrayInputStream(jbyte* bytes, int len, jboolean copyBytes = false); 
      ByteArrayInputStream(jakelib::util::ByteArray* byteArray, jboolean copyBytes = false); 
      ~ByteArrayInputStream(); 

      int read();

      int read(jbyte* b, int offset, int len);

      void close();

      void reset();

      int skip(int n);

      int available();

      void setBlocking(jboolean on = true) {};
  
    protected:

      jakelib::util::ByteArray* byteArray;

      jboolean copyBytes;

      int pos;

      int count;

      jbyte* buf;

      JAKELIB_DECLARE_CLASS(ByteArrayInputStream);
    };
  }
}
#endif

