// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: FileInputStream.h,v 1.21 2003/09/13 08:46:07 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_FILEINPUTSTREAM_H
# define INCLUDE_JAKELIB2_IO_FILEINPUTSTREAM_H
# include "InputStream.h"

# if defined(JAKELIB_WIN32API)
#  include <windows.h>
# endif

namespace jakelib {
  namespace io {
    class File;

    /**
     * This class is a stream that reads its bytes from a file.
     *
     * @class FileInputStream
     * @version $Id: FileInputStream.h,v 1.21 2003/09/13 08:46:07 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class FileInputStream : public InputStream
      {
      public:

        /**
         * Opens the specified file for reading.
         */
	FileInputStream(File* file); 

        /**
         * Opens the specified file for reading.
         */
	FileInputStream(char* filename); 

        /**
         * Opens the specified file for reading.
         */
	FileInputStream(jakelib::lang::String* filename); 

	~FileInputStream();

	int read();

	int read(jbyte* b, int offset, int len);

	void close();

	void reset();

	int skip(int n);

	int available();

	void setBlocking(jboolean on) {};
  
      protected:

#if defined(JAKELIB_WIN32API)
        HANDLE handle;
#else
	int handle;
#endif
  
	void init(jakelib::lang::String* filename);

	JAKELIB_DECLARE_CLASS(FileInputStream);
      };

  }
}
#endif

