// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: FileReader.h,v 1.6 2003/09/02 16:20:04 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_FILEREADER_H
# define INCLUDE_JAKELIB2_IO_FILEREADER_H
# include "InputStreamReader.h"
# include "File.h"

namespace jakelib {
  namespace io {

    /**
     * @brief  This class provides a convenient way to set up a \c Reader
     * to read from a file.
     *
     * It opens the specified file for reading and creates
     * the \c InputStreamReader to read from the 
     * resulting \c FileInputStream. This class can only be used
     * to read from files using the default character encoding. Use
     * \c InputStreamReader directly to use a non-default encoding.
     *
     * @class FileReader
     * @version $Id: FileReader.h,v 1.6 2003/09/02 16:20:04 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class FileReader : public InputStreamReader
      {
      public:

        /**
         * @brief This method initializes a \c FileReader instance to read from
         * the specified named file.
         */
	FileReader(jakelib::lang::String* filename);

        /**
         * @brief This method initializes a \c FileReader instance to read from
         * the specified named file.
         */
	FileReader(char* filename);

        /**
         * @brief This method initializes a \c FileReader instance to read from
         * the specified \c File object.
         */
	FileReader(File* file);

	JAKELIB_DECLARE_CLASS(FileReader);
      };
  }
}
#endif

