// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: FilenameFilter.h,v 1.4 2003/09/13 08:46:07 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_FILENAMEFILTER_H
# define INCLUDE_JAKELIB2_IO_FILENAMEFILTER_H


namespace jakelib {
  namespace io {
    class File;

    /**
     * This interface has one method which is used for filtering filenames
     * returned in a directory listing. It is currently used by the 
     * \c File::list() method.
     *
     * The method in this interface determines if a particular file should
     * or should not be included in the file listing.
     *
     * @class FilenameFilter
     * @version $Id: FilenameFilter.h,v 1.4 2003/09/13 08:46:07 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class FilenameFilter : public jakelib::lang::Interface
    {
    public:

      FilenameFilter();

      /**
       * This method determines whether or not a given file should be included
       * in a directory listing.
       *
       * @param dir  The \c File instance for the directory being read
       * @param name The name of the file to test
       *
       * @return \c true if the file should be included in the list,
       *         \c false otherwise.
       */
      virtual jboolean accept(File *dir, 
                              jakelib::lang::String *name) = 0;

      JAKELIB_DECLARE_INTERFACE(FilenameFilter);
    };
  }
}
#endif

