/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: IOException.h,v 1.1 2003/01/15 12:12:37 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_IOEXCEPTION_H
# define INCLUDE_JAKELIB2_IO_IOEXCEPTION_H
#include "../lang/Exception.h"

namespace jakelib {
  namespace io {

    /*****************************************************************************\
     * IOException                                                                |
     *****************************************************************************/
    class IOException : public jakelib::lang::Exception
      {
      public:
	IOException(jakelib::lang::String* msg = null);

	JAKELIB_DECLARE_CLASS(IOException);
      };


    /*****************************************************************************\
     * FileNotFoundException                                                      |
     *****************************************************************************/
    class FileNotFoundException : public IOException
      {
      public:

	FileNotFoundException(jakelib::lang::String* msg,
                              jakelib::lang::String *filename);

        jakelib::lang::String* getFilename();

      protected:

        jakelib::lang::String *filename;

	JAKELIB_DECLARE_CLASS(FileNotFoundException);
      };


    /*****************************************************************************\
     * EOFException                                                               |
     *****************************************************************************/
    class EOFException : public IOException
      {
      public:
	EOFException(jakelib::lang::String* msg = null);

	JAKELIB_DECLARE_CLASS(EOFException);
      };


    /*****************************************************************************\
     * MalformedURLException                                                      |
     *****************************************************************************/
    class MalformedURLException : public IOException
      {
      public:
	MalformedURLException(jakelib::lang::String* msg = null);

	JAKELIB_DECLARE_CLASS(MalformedURLException);
      };


    /*****************************************************************************\
     * UnsupportedEncodingException                                               |
     *****************************************************************************/
    class UnsupportedEncodingException : public IOException
      {
      public:
	UnsupportedEncodingException(jakelib::lang::String* msg = null);

	JAKELIB_DECLARE_CLASS(UnsupportedEncodingException);
      };


    /*****************************************************************************\
     * ConversionBufferFullException                                              |
     *****************************************************************************/
    class ConversionBufferFullException : public IOException
      {
      public:
	ConversionBufferFullException(jakelib::lang::String* msg = null);

	JAKELIB_DECLARE_CLASS(ConversionBufferFullException);
      };


    /*****************************************************************************\
     * UnknownCharacterException                                                  |
     *****************************************************************************/
    class UnknownCharacterException : public IOException
      {
      public:
	UnknownCharacterException(jakelib::lang::String* msg = null);

	JAKELIB_DECLARE_CLASS(UnknownCharacterException);
      };

  }
}

#endif

