/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: InputStreamReader.h,v 1.12 2003/09/02 17:17:03 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_INPUTSTREAMREADER_H
# define INCLUDE_JAKELIB2_IO_INPUTSTREAMREADER_H
# include "Reader.h"

namespace jakelib {
  namespace util {
    class CharArray;
  }
  namespace text {
    namespace enc {
      class ByteToCharConverter;
    }
  }
  namespace io {
    class InputStream;

    /**
     * An \c InputStreamReader is a Reader that can be set-up to use
     * a certain character encoding. For a list of available encodings
     * see jakelib::text::enc::ByteToCharConverter.
     *
     * @class InputStreamReader
     * @version $Id: InputStreamReader.h,v 1.12 2003/09/02 17:17:03 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     * @see jakelib::text::enc::ByteToCharConverter
     */
    class InputStreamReader : public Reader
      {
      private:
	InputStream* input;

      public:
	InputStreamReader(InputStream* input, jakelib::text::enc::ByteToCharConverter* converter = null);

        /**
         * Create a new \c InputStreamReader with the specified encoding.
         *
         * @param input The InputStream.
         * @param encoding The encoding name
         */
	InputStreamReader(InputStream* input, jakelib::lang::String* encoding);

	~InputStreamReader();

	int read();

	int read(jchar* buf, int offset, int len);

	jboolean ready();

	void close();

      private:
	/**
	 * @throws IOException If the Input stream is closed
	 */
	void ensureOpen();

	static const int bufferSize;

	jakelib::text::enc::ByteToCharConverter* converter;

	jakelib::util::CharArray* charBuffer;

        void init(InputStream* input, jakelib::text::enc::ByteToCharConverter* converter = null);

	JAKELIB_DECLARE_CLASS(InputStreamReader);
      };

  }
}
#endif

