// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: OutputStreamWriter.h,v 1.10 2003/09/07 08:11:33 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_OUTPUTSTREAMWRITER_H
# define INCLUDE_JAKELIB2_IO_OUTPUTSTREAMWRITER_H
# include "Writer.h"

namespace jakelib {
  namespace util {
    class ByteArray;
  }
  namespace text {
    namespace enc {
      class CharToByteConverter;
    }
  }
  namespace io {
    class OutputStream;

    /**
     *
     * @class OutputStreamWriter
     * @version $Id: OutputStreamWriter.h,v 1.10 2003/09/07 08:11:33 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class OutputStreamWriter : public Writer
      {
      public:
	OutputStreamWriter(OutputStream* output,
			   jakelib::text::enc::CharToByteConverter* converter = null);
	OutputStreamWriter(OutputStream* output,
			   jakelib::lang::String* encoding);

	~OutputStreamWriter();

	jakelib::lang::String* getEncoding();

	void write(jchar* buf, int offset, int len);

	void write(int c);

	void close();

	void flush();

      private:
	OutputStream* output;

	jakelib::text::enc::CharToByteConverter* converter;

	jakelib::util::ByteArray* byteBuffer;

	static const int bufferSize;

	/**
	 * @throws IOException If the Output stream is closed
	 */
	void ensureOpen();

	void flushBuffer();

	JAKELIB_DECLARE_CLASS(OutputStreamWriter);
      };

  }
}
#endif

