// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PipeInputStream.h,v 1.22 2003/09/13 08:46:07 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_PIPEINPUTSTREAM_H
# define INCLUDE_JAKELIB2_IO_PIPEINPUTSTREAM_H
# include "InputStream.h"

# if defined(JAKELIB_WIN32API)
#  include <windows.h>
# endif


namespace jakelib {
  namespace io {

    /**
     * A \c PipeInputStream allows receiving data through a pipe from
     * another process (IPC - Inter Process Communication).
     *
     * A PipeInputStream can be retreived from a Process object by 
     * calling its \c getInputStream() or \c getErrorStream() method.
     *
     * @class PipeInputStream
     * @version $Id: PipeInputStream.h,v 1.22 2003/09/13 08:46:07 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class PipeInputStream : public InputStream
    {
    public:

#if defined(JAKELIB_WIN32API)
      /**
       * System-dependend constructor.
       */
      PipeInputStream(HANDLE p);
#else
      /**
       * System-dependend constructor.
       */
      PipeInputStream(int p); 
#endif

      ~PipeInputStream(); 

      int read();

      int read(jbyte* b, int offset, int len);

      void close();

      void reset();

      void setBlocking(jboolean on = true);
  
    protected:

#if defined(JAKELIB_WIN32API)
      HANDLE pipe;
#else
      int pipe;
#endif

      JAKELIB_DECLARE_CLASS(PipeInputStream);
    };

  }
}
#endif

