// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PipeOutputStream.h,v 1.19 2003/09/13 08:46:07 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_IO_PIPEOUTPUTSTREAM_H
# define INCLUDE_JAKELIB2_IO_PIPEOUTPUTSTREAM_H
# include "OutputStream.h"

# if defined(JAKELIB_WIN32API)
#  include <windows.h>
# endif

namespace jakelib {
  namespace io {

    /**
     * A \c PipeOutputStream allows sending data through a pipe from
     * one process to another (IPC - Inter Process Communication).
     *
     * A PipeOutputStream can be retreived from a Process object by 
     * calling its \c getOutputStream() method.
     *
     * @class PipeOutputStream
     * @version $Id: PipeOutputStream.h,v 1.19 2003/09/13 08:46:07 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class PipeOutputStream : public OutputStream
    {
    public:

#if defined(JAKELIB_WIN32API)
      /**
       * System-dependend constructor.
       */
      PipeOutputStream(HANDLE pipe);
#else
      /**
       * System-dependend constructor.
       */
      PipeOutputStream(int pipe); 
#endif

      ~PipeOutputStream(); 

      void write(int b);

      void write(jbyte* b, int offset, int len);

      void close();
  
    protected:

#if defined(JAKELIB_WIN32API)
      HANDLE pipe;
#else
      int pipe;
#endif

      JAKELIB_DECLARE_CLASS(PipeOutputStream);
    };
  }
}
#endif

