/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: Cloneable.h,v 1.4 2003/01/25 12:34:40 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_LANG_CLONEABLE_H
# define INCLUDE_JAKELIB2_LANG_CLONEABLE_H

namespace jakelib {
  namespace lang {

    /**
     * This interface should be implemented by classes wishing to
     * support of override <code>Object.clone()</code>.  The default
     * behaviour of <code>clone()</code> performs a shallow copy, but
     * subclasses often change this to perform a deep copy.  Therefore,
     * it is a good idea to document how deep your clone will go.
     * If <code>clone()</code> is called on an object which does not
     * implement this interface, a <code>CloneNotSupportedException</code>
     * will be thrown.
     *
     * <p>This interface is simply a tagging interface; it carries no
     * requirements on methods to implement.  However, it is typical for
     * a Cloneable class to implement at least <code>equals</code>,
     * <code>hashCode</code>, and <code>clone</code>, sometimes
     * increasing the accessibility of clone to be public. The typical
     * implementation of <code>clone</code> invokes <code>super.clone()</code>
     * rather than a constructor, but this is not a requirement.
     *
     * <p>If an object that implement Cloneable should not be cloned,
     * simply override the <code>clone</code> method to throw a
     * <code>CloneNotSupportedException</code>.
     *
     * <p>All array types implement Cloneable, and have a public
     * <code>clone</code> method that will never fail with a
     * <code>CloneNotSupportedException</code>.
     *
     * @author Paul Fisher
     * @author Eric Blake <ebb9@email.byu.edu>
     * @author Warren Levy <warrenl@cygnus.com>
     * @author Alex Fabijanic <fabijanica@nucorsteel.com>(jakelib2 port)
     * @see Object#clone()
     * @see CloneNotSupportedException
     * @since 1.0
     * @status updated to 1.4
     */
    class Cloneable : public jakelib::lang::Interface
    {

      JAKELIB_DECLARE_INTERFACE(Cloneable);
    };
  }
}

#endif
