/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: StackTrace.h,v 1.4 2003/02/19 08:33:02 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_LANG_STACKTRACE_H
# define INCLUDE_JAKELIB2_LANG_STACKTRACE_H

namespace jakelib {
  namespace lang {
    /**
     *
     * @class StackTrace
     * @version $Id: StackTrace.h,v 1.4 2003/02/19 08:33:02 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class StackTrace
      {
      public:

        /**
         * Creates a new \c StackTrace with a given size.
         */
        StackTrace(int size = 100);

        /**
         * Pushes the given element on top of the stack.
         */
        void push(TmpStackTraceElement *ste);

        /**
         * Pops the top-most element from the stack.
         */
        TmpStackTraceElement* pop();

        /**
         * Returns the number of entries.
         */
        int getElemCount();

        /**
         * Returns the \c StackTraceElement at the given position.
         *
         * Warning: Don't reference objects returned by \c get() since
         * they are deleted as the stack shrinks.
         */
        TmpStackTraceElement *get(int idx);

        /**
         * Frees all allocates resources.
         */
        void destroy();

      protected:

        /** The stack size in number of elements. */
        int size;

        /** Index of the next free stack position. */
        int nextFree;

        /** The actual stack */
        TmpStackTraceElement **stack;
      };
  }
}

#endif
