/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: InetAddress.h,v 1.13 2003/09/11 11:58:19 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_NET_INETADDRESS_H
# define INCLUDE_JAKELIB2_NET_INETADDRESS_H

namespace jakelib {
  namespace net {

    /**
     * This class encapsulates an IP address.
     *
     * @class InetAddress
     * @version $Id: InetAddress.h,v 1.13 2003/09/11 11:58:19 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class InetAddress : public jakelib::lang::Object
      {
      public:
	/**
	 * @brief Creates a new <tt>InetAddress</tt> with a given IP address.
	 *
	 * @param addr A 4-jbyte array containing the IP/4 address.
	 */
	InetAddress(char* addr);

	~InetAddress();

	/**
	 * @brief Returns the IP address in "aaa.bbb.ccc.ddd" format.
	 */
	jakelib::lang::String* getHostAddress();

	/**
	 * @brief Returns the host name.
	 *
	 * @throws IOException If the host name cannot be found.
	 */
	jakelib::lang::String* getHostName();

	/**
	 * @brief Returns the IP address in a 4-jbyte array.
	 */
	char* getAddress();

        /**
         * Returns a human-readable strign representation
         */
        jakelib::lang::String* toString();

	/**
	 * @brief Return a new <tt>InetAddress</tt> object for the local host.
	 */
	static InetAddress getLocalHost();

	/**
	 * Returns a new <tt>InetAddress</tt> object for the named host.
	 *
	 * @throws IOException If the host name could not be resolved.
	 */
	static InetAddress getByName(char* name);
  
      protected:
	char addr[4];

	JAKELIB_DECLARE_CLASS(InetAddress);
      };

  }
}
#endif

