// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: ServerSocket.h,v 1.13 2003/09/05 15:17:38 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_NET_SERVERSOCKET_H
# define INCLUDE_JAKELIB2_NET_SERVERSOCKET_H

namespace jakelib {
  namespace net {

    class InetAddress;
    class Socket;

    /**
     *
     *
     * @class ServerSocket
     * @version $Id: ServerSocket.h,v 1.13 2003/09/05 15:17:38 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class ServerSocket : public jakelib::lang::Object
      {
      public:

	ServerSocket(int port);

	ServerSocket(InetAddress* adr);

	JAKELIB_DECLARE_CLASS(ServerSocket);

	~ServerSocket();
  
	/**
	 * Listens for a connection to be made to this socket and accepts 
	 * it. The method blocks until a connection is made. 
	 *
	 * @throws IOException If an I/O error occurs when waiting for a connection.
	 */
	Socket* accept();
  
	/**
	 * Returns the port on which this socket is listening.
	 *
	 * @return The port number to which this socket is listening.
	 */
	int getLocalPort();
  
	/**
	 * Closes this socket. 
	 *
	 * @throws IOException  if an I/O error occurs when closing the socket.
	 */
	void close();
  
      protected:
        /** Holds the port address this server is listening to. */
	int port;

        /** The system-dependend handle for the server socket. */
	JL2_SOCKET sock;
  
	void init(int port);
      };

  }
}
#endif

