// -*- c++ -*-

/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: ParseException.h,v 1.3 2003/09/17 08:01:54 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_TEXT_PARSEEXCEPTION_H
# define INCLUDE_JAKELIB2_TEXT_PARSEEXCEPTION_H

#include "../lang/Exception.h"

namespace jakelib {
  namespace text {

    /**
     * @author Alex Fabijanic <fabijanica@nucorsteel.com>(jakelib2 port)
     * @see Format
     * @see FieldPosition
     */
    class ParseException : public jakelib::lang::Exception
    {
    public:

      /**
       * This method initializes a new instance of ParseException
       * with a detailed error message and a error position.
       *
       * @param msg The descriptive message describing the error.
       * @param offset The position where the error was encountered.
       */
      ParseException(jakelib::lang::String* msg, jint offset);

      /**
       * This method returns the position where the error occurred.
       *
       * @return The position where the error occurred.
       */
      jint getErrorOffset();

    private:

      /**
       */
      jint errorOffset;

      JAKELIB_DECLARE_CLASS(ParseException);
    };
  }
}

#endif
