/*
 * Jakelib2 - General purpose C++ library
 * Copyright (C) 2001 Florian Wolff  (florian@donuz.de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: BitSet.h,v 1.14 2002/09/15 08:23:28 florian Exp $
 */

#ifndef INCLUDE_JAKELIB2_UTIL_BITSET_H
# define INCLUDE_JAKELIB2_UTIL_BITSET_H

namespace jakelib {
  namespace util {

    /**
     * @class BitSet
     * @version $Id: BitSet.h,v 1.14 2002/09/15 08:23:28 florian Exp $
     * @author Florian 'Overflo' Wolff (florian@donuz.de)
     */
    class BitSet : public jakelib::lang::Object
      {
      public:
	BitSet();
	BitSet(int nbits);

	JAKELIB_DECLARE_CLASS(BitSet);

	~BitSet();

	int length();
	void set(int bitIndex);
	void clear(int bitIndex);
	void andNotOp(BitSet* set);
	jboolean get(int bitIndex);
	void andOp(BitSet* set);
	void orOp(BitSet* set);
	void xorOp(BitSet* set);
	int hashCode();
	int size();
	jboolean equals(jakelib::lang::Object* obj);
	jakelib::lang::Object* clone();
	jakelib::lang::String* toString();
  
      private:
	static int ADDRESS_BITS_PER_UNIT;
	static int BITS_PER_UNIT;
	static int BIT_INDEX_MASK;
	static int UNIT_SIZE;

	long* bits;
	int bits_length;
	int unitsInUse;
  
	static int unitIndex(int bitIndex);
	static long bit(int bitIndex);
	void recalculateUnitsInUse();
	void ensureCapacity(int unitsRequired);
	void init(int nbits);
      };

  }
}
#endif

