#
# Jakelib2
#
# AC_CHECK_JAKELIB2(MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND ]])
# Test for Jakelib2, and define JAKELIB_CFLAGS and JAKELIB_LIBS
#
# Configure paths for Jakelib2
# Florian Wolff   2002-05-26

AC_DEFUN(AC_CHECK_JAKELIB2,
[
  min_jakelib2_version=$1
  too_old="0"
  no_jakelib2="0"
  version_mismatch="0"

  AC_ARG_WITH(jakelib2-prefix,[  --with-jakelib2-prefix=PFX   Prefix where Jakelib2 is installed (optional)],
            jakelib2_config_prefix="$withval", jakelib2_config_prefix="")

  if test x$jakelib2_config_prefix != x ; then
     jakelib2_config_args="$jakelib2_config_args --prefix=$jakelib2_config_prefix"
     if test x${JAKELIB2_CONFIG+set} != xset ; then
        JAKELIB2_CONFIG=$jakelib2_config_prefix/bin/jakelib2-config
     fi
  fi

  AC_PATH_PROG(JAKELIB2_CONFIG, jakelib2-config, no)
  AC_MSG_CHECKING(for JAKELIB2 - version >= $min_jakelib2_version)
  no_jakelib2=""
  if test "$JAKELIB2_CONFIG" = "no" ; then
    no_jakelib2=yes
    AC_MSG_RESULT(no)
    echo "*** The jakelib2-config script installed by Jakelib2 could not be found"
    echo "*** If Jakelib2 was installed in PREFIX, make sure PREFIX/bin is in"
    echo "*** your path."
    echo "*** If you don't have Jakelib2 installed you can get it from"
    echo "*** http://www.jakelib.org"
  else
    JAKELIB2_CFLAGS=`$JAKELIB2_CONFIG $jakelib2_config_args --cflags`
    JAKELIB2_LIBS=`$JAKELIB2_CONFIG $jakelib2_config_args --libs`
    jakelib2_have_major_version=`$JAKELIB2_CONFIG $jakelib2_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)\([[a-z]]*\)/\1/'`
    jakelib2_have_minor_version=`$JAKELIB2_CONFIG $jakelib2_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)\([[a-z]]*\)/\2/'`
    jakelib2_have_micro_version=`$JAKELIB2_CONFIG $jakelib2_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)\([[a-z]]*\)/\3/'`

    jakelib2_want_major_version=`echo $min_jakelib2_version | sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)\([[a-z]]*\)/\1/'`
    jakelib2_want_minor_version=`echo $min_jakelib2_version | sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)\([[a-z]]*\)/\2/'`
    jakelib2_want_micro_version=`echo $min_jakelib2_version | sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)\([[a-z]]*\)/\3/'`

    if test `expr $jakelib2_have_major_version "<" $jakelib2_want_major_version` = "1"; then
        too_old="1"
    fi
    if test `expr $jakelib2_have_minor_version "<" $jakelib2_want_minor_version` = "1"; then
        too_old="1"
    fi
    if test `expr $jakelib2_have_micro_version "<" $jakelib2_want_micro_version` = "1"; then
        too_old="1"
    fi

    if test "$too_old" = "1"; then
      AC_MSG_RESULT([no])
      no_jakelib2="yes"

      echo "*** An old version of Jakelib2 ($jakelib2_have_major_version.$jakelib2_have_minor_version.$jakelib2_have_micro_version) was found."
      echo "*** You need at least version $jakelib2_want_major_version.$jakelib2_want_minor_version.$jakelib2_want_micro_version."
      echo "*** The latest version of Jakelib2 is always available"
      echo "*** from http://www.jakelib.org."
    else    
      AC_MSG_RESULT([yes])
    fi

#    AC_MSG_CHECKING([if a simple test program works])
#    AC_TRY_RUN([
#include <jakelib2/config.h>
#void main() {
#if JAKELIB_MAJOR_VERSION = $jakelib2_have_major_version && JAKELIB_MINOR_VERSION = $jakelib2_have_minor_version && JAKELIB_MICRO_VERSION = $jakelib2_have_micro_version
#  return 0;
#else
#  return 1;
#endif
#}
#], AC_MSG_RESULT(yes), AC_MSG_RESULT(no))


#    AC_MSG_CHECKING([if a simple test program works])
#    AC_TRY_RUN([
##include <jakelib2/config.h>
##include <stdio.h>
#void main() {
#  if ((JAKELIB_MAJOR_VERSION != $jakelib2_have_major_version) ||
#      (JAKELIB_MINOR_VERSION != $jakelib2_have_minor_version) ||
#      (JAKELIB_MICRO_VERSION != $jakelib2_have_micro_version))
#    {
#      printf("\n*** 'jakelib2-config --version' returned %d.%d.%d, but Jakelib2 (%d.%d.%d)\n", 
#             $jakelib2_have_major_version, $jakelib2_have_minor_version, $jakelib2_have_micro_version,
#             JAKELIB_MAJOR_VERSION, JAKELIB_MINOR_VERSION, JAKELIB_MICRO_VERSION);
#      printf ("*** was found! If jakelib2-config was correct, then it is best\n");
#      printf ("*** to remove the old version of Jakelib2.\n");
#      return 1;
#    } 
#
#  return 90;
#}
#], AC_MSG_RESULT(yes $?), AC_MSG_RESULT(no $?)  )

    if test "$version_mismatch" = "1"; then
      no_jakelib2="yes"

      echo "*** "
    fi
  fi

  if test "$no_jakelib2" = "yes"; then
    true
    [$3]
  else
    true

    AC_SUBST(JAKELIB_LDADD, ${JAKELIB2_LIBS})
    AC_SUBST(JAKELIB_CFLAGS, ${JAKELIB2_CFLAGS})

    [$2]
  fi
])

